@@ -11,20 +11,36 @@ from redex.wildcards import *
 def is_in(char, string) -> bool:
     if char in wildcard.keys():
         for wchar in wildcard[char]:
-            if wchar == string[0]:
+            if wchar in string:
                 return True
     else:
         return char in string
+    
+def is_in_end(char, string) -> bool:
+    if char in wildcard.keys():
+        for wchar in wildcard[char]:
+            if wchar == string[-1]:
+                return True
+    else:
+        return char == string
+
+def is_in_start(char, string) -> bool:
+    if char in wildcard.keys():
+        for wchar in wildcard[char]:
+            if wchar == string[0]:
+                return True
+    else:
+        return char == string
 
 # actions
 
 def startswith(sub_query, string) -> bool:
     sub_query = sub_query.split(':')[1]
-    return is_in(sub_query, string[:len(sub_query)])
+    return is_in_start(sub_query, string[:len(sub_query)])
 
 def endswith(sub_query, string) -> bool:
     sub_query = sub_query.split(':')[1]
-    return is_in(sub_query, string[-len(sub_query):])
+    return is_in_end(sub_query, string[-len(sub_query):])
 
 def contains(sub_query, string) -> bool:
     sub_query = sub_query.split(':')[1]
@@ -69,7 +85,7 @@ def sequence(sub_query, string) -> bool:
 def location(sub_query, string) -> bool:
     sub_query = sub_query.split(':')[1]
     char = list(sub_query[1:-1].split(','))[0]
-    location = int(list(sub_query[1:-1].split(','))[1])
+    location = int(list(sub_query[1:-1].split(','))[1])    
     if location < len(string) - 1:
         return is_in(char, string[location])
     else:
